@@ -12,7 +12,6 @@ use crate::{
     domain::{Record, RecordAdd, RecordUpdate},
 };
 use chrono::{DateTime, Duration, Utc};
-use reqwest;
 use serde::Serialize;
 use std::collections::HashMap;
 use urlencoding::encode;
@@ -95,7 +94,7 @@ impl AuditorClientBuilder {
     pub fn new() -> AuditorClientBuilder {
         AuditorClientBuilder {
             address: "http://127.0.0.1:8080".into(),
-            timeout: Duration::seconds(30),
+            timeout: Duration::try_seconds(30).expect("This should never fail"),
         }
     }
 
@@ -129,7 +128,8 @@ impl AuditorClientBuilder {
     /// * `timeout` - Timeout in seconds.
     #[must_use]
     pub fn timeout(mut self, timeout: i64) -> Self {
-        self.timeout = Duration::seconds(timeout);
+        self.timeout = Duration::try_seconds(timeout)
+            .unwrap_or_else(|| panic!("Could not convert {} to duration", timeout));
         self
     }
 
@@ -644,7 +644,8 @@ impl AuditorClient {
     #[tracing::instrument(
         name = "Sending a record to AUDITOR server.",
         skip(self, record),
-        fields(record_id = %record.record_id)
+        fields(record_id = %record.record_id),
+        level = "debug"
     )]
     pub async fn add(&self, record: &RecordAdd) -> Result<(), ClientError> {
         let response = self
@@ -1156,7 +1157,12 @@ mod tests {
         Mock::given(method("GET"))
             .and(path("/health_check"))
             .respond_with(
-                ResponseTemplate::new(200).set_delay(Duration::seconds(180).to_std().unwrap()),
+                ResponseTemplate::new(200).set_delay(
+                    Duration::try_seconds(180)
+                        .expect("This should never fail")
+                        .to_std()
+                        .expect("This should never fail"),
+                ),
             )
             .expect(1)
             .mount(&mock_server)
@@ -1182,7 +1188,12 @@ mod tests {
         Mock::given(method("GET"))
             .and(path("/health_check"))
             .respond_with(
-                ResponseTemplate::new(200).set_delay(Duration::seconds(180).to_std().unwrap()),
+                ResponseTemplate::new(200).set_delay(
+                    Duration::try_seconds(180)
+                        .expect("This should never fail")
+                        .to_std()
+                        .expect("This should never fail"),
+                ),
             )
             .expect(1)
             .mount(&mock_server)
