@@ -4,7 +4,7 @@ use fake::{Fake, Faker};
 
 #[tokio::test]
 async fn update_returns_a_404_for_non_existing_record() {
-    // Arange
+    // Arrange
     let app = spawn_app().await;
     let client = reqwest::Client::new();
 
@@ -12,7 +12,7 @@ async fn update_returns_a_404_for_non_existing_record() {
     let body: RecordTest = Faker.fake();
 
     let response = client
-        .post(&format!("{}/update", &app.address))
+        .put(&format!("{}/record", &app.address))
         .header("Content-Type", "application/json")
         .json(&body)
         .send()
@@ -24,7 +24,7 @@ async fn update_returns_a_404_for_non_existing_record() {
 
 #[tokio::test]
 async fn update_returns_a_200_for_valid_form_data() {
-    // Arange
+    // Arrange
     let app = spawn_app().await;
     let client = reqwest::Client::new();
 
@@ -35,7 +35,7 @@ async fn update_returns_a_200_for_valid_form_data() {
     body.stop_time = None;
 
     let response = client
-        .post(&format!("{}/add", &app.address))
+        .post(&format!("{}/record", &app.address))
         .header("Content-Type", "application/json")
         .json(&body)
         .send()
@@ -48,7 +48,7 @@ async fn update_returns_a_200_for_valid_form_data() {
     let body = body.with_stop_time("2022-03-01T13:00:00-00:00");
 
     let response = client
-        .post(&format!("{}/update", &app.address))
+        .put(&format!("{}/record", &app.address))
         .header("Content-Type", "application/json")
         .json(&body)
         .send()
